@@ -1,6 +1,6 @@
 package RDF::RDFa::Parser::OpenDocumentObjectModel;
 
-our $VERSION = '1.09_11';
+our $VERSION = '1.096_01';
 our @Types = qw(
 	application/vnd.oasis.opendocument.chart
 	application/vnd.oasis.opendocument.database
@@ -19,6 +19,7 @@ our @Types = qw(
 	);
 
 use File::Temp qw':seekable';
+use Scalar::Util qw'blessed';
 use URI;
 use URI::file;
 use XML::LibXML qw':all';
@@ -41,7 +42,7 @@ sub new
 
 sub usable
 {
-	return UNIVERSAL::can('Archive::Zip', 'new');
+	return Archive::Zip->can('new');
 }
 
 sub parse_archive
@@ -124,7 +125,7 @@ sub parse_file
 {
 	my ($self, $file, $baseurl) = @_;
 
-	unless (UNIVERSAL::isa($file, 'URI'))
+	unless (blessed($file) && $file->isa('URI'))
 	{
 		if ($file =~ /^[a-z0-9_\.-]+:\S+$/i)
 		{
@@ -152,4 +153,51 @@ sub parse_file
 	return $self->parse_string($content, $baseurl);
 }
 
-1;
\ No newline at end of file
+__PACKAGE__
+__END__
+
+=head1 NAME
+
+RDF::RDFa::Parser::OpenDocumentObjectModel - DOM representation of an OpenDocument Format 1.2 file
+
+=head1 DESCRIPTION
+
+You should hopefully not need to use this module to be able to use RDF::RDFa::Parser. It's
+used internally by the parser to deal with OpenDocument Format input.
+
+This class provides a C<new> constructor and C<parse_file>, C<parse_fh> and C<parse_string>
+methods offering rought compatibility with the parsing interface described in L<XML::LibXML::Parser>.
+
+It represents an OpenDocument Format 1.2 file (internally a ZIP file containing various XML,
+RDF/XML and other files) into a single L<XML::LibXML::Document> with a root element
+C<od:Document>. The root element has several child elements with tag names C<od:Data>
+and C<od:Meta> which each contain a single child corresponding to the root element of
+(respectively) an XML or RDF/XML file found inside the ZIP. (C<od:Data> and C<od:Meta> elements
+each have a C<file> attribute indicating which file.) This representation is necessarily
+different to the "Flat XML" format offered by OpenOffice - trust me.
+
+The "od" namespace URI is L<http://purl.org/NET/cpan-uri/dist/RDF-RDFa-Parser/opendocument-dom-wrapper>.
+
+=head1 SEE ALSO
+
+L<RDF::RDFa::Parser>.
+
+L<XML::LibXML::Parser>,
+L<HTML::HTML5::Parser>.
+
+=head1 AUTHOR
+
+Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
+
+=head1 COPYRIGHT AND LICENCE
+
+Copyright 2008-2012 Toby Inkster
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=head1 DISCLAIMER OF WARRANTIES
+
+THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
+WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
+MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
